@@ -38,7 +38,7 @@ import sys
 
 from tvb.basic.config import stored
 from tvb.basic.config.environment import Environment
-from tvb.basic.config.settings import ClusterSettings, DBSettings, VersionSettings, WebSettings
+from tvb.basic.config.settings import ClusterSettings, DBSettings, VersionSettings, WebSettings, HPCSettings
 
 
 class BaseSettingsProfile(object):
@@ -66,12 +66,14 @@ class BaseSettingsProfile(object):
         self.KEYCLOAK_LOGIN_ENABLED = self.manager.get_attribute(stored.KEY_ENABLE_KC_LOGIN, False, eval)
         self.KEYCLOAK_WEB_CONFIG = self.manager.get_attribute(stored.KEY_KC_WEB_CONFIGURATION, '')
         self.TVB_STORAGE = self.manager.get_attribute(stored.KEY_STORAGE, self.FIRST_RUN_STORAGE, str)
+        self.UPLOAD_KEY_PATH = self.manager.get_attribute(stored.KEY_UPLOAD_PRIVATE_KEY_PATH, None, str)
         self.TRACE_USER_ACTIONS = self.manager.get_attribute(stored.KEY_TRACE_USER_ACTIONS, False, eval)
         self.TVB_LOG_FOLDER = os.path.join(self.TVB_STORAGE, "logs")
         self.TVB_TEMP_FOLDER = os.path.join(self.TVB_STORAGE, "TEMP")
 
         self.env = Environment()
         self.cluster = ClusterSettings(self.manager)
+        self.hpc = HPCSettings(self.manager)
         self.web = WebSettings(self.manager)
         self.db = DBSettings(self.manager, self.DEFAULT_STORAGE, self.TVB_STORAGE)
         self.version = VersionSettings(self.manager, self.BIN_FOLDER)
@@ -122,6 +124,7 @@ class BaseSettingsProfile(object):
         """
         self.db.MAX_CONNECTIONS = self.db.MAX_ASYNC_CONNECTIONS
         self.cluster.IN_OPERATION_EXECUTION_PROCESS = True
+        self.hpc.IN_OPERATION_EXECUTION_PROCESS = True
 
     def initialize_profile(self):
         """
