@@ -43,8 +43,9 @@ KEY_ADMIN_DISPLAY_NAME = 'ADMINISTRATOR_DISPLAY_NAME'
 KEY_ADMIN_NAME = 'ADMINISTRATOR_NAME'
 KEY_ADMIN_PWD = 'ADMINISTRATOR_PASSWORD'
 KEY_ADMIN_EMAIL = 'ADMINISTRATOR_EMAIL'
-KEY_ADMIN_GIDS = 'ADMINISTRATOR_GIDS'
+KEY_ADMINS_GROUP = 'ADMINISTRATORS_GROUP'
 KEY_STORAGE = 'TVB_STORAGE'
+KEY_UPLOAD_PRIVATE_KEY_PATH = 'UPLOAD_KEY_PATH'
 KEY_KC_CONFIGURATION = 'KEYCLOAK_CONFIGURATION'
 KEY_KC_WEB_CONFIGURATION = 'KEYCLOAK_WEB_CONFIGURATION'
 KEY_ENABLE_KC_LOGIN = 'ENABLE_KEYCLOAK_LOGIN'
@@ -60,6 +61,11 @@ KEY_DB_URL = 'URL_VALUE'
 KEY_URL_VERSION = 'URL_TVB_VERSION'
 KEY_CLUSTER = 'DEPLOY_CLUSTER'
 KEY_CLUSTER_SCHEDULER = 'CLUSTER_SCHEDULER'
+KEY_HPC = 'RUN_ON_HPC'
+KEY_HPC_INTERVAL = 'HPC_SYNC_BACKGROUND_JOB_INTERVAL'
+KEY_CRYPT_PASSDIR = 'CRYPT_PASSDIR'
+KEY_CRYPT_DATADIR = 'CRYPT_DATADIR'
+KEY_HPC_COMPUTE_SITE = 'HPC_COMPUTE_SITE'
 KEY_MAX_THREAD_NR = 'MAXIMUM_NR_OF_THREADS'
 KEY_MAX_RANGE_NR = 'MAXIMUM_NR_OF_OPS_IN_RANGE'
 KEY_MAX_NR_SURFACE_VERTEX = 'MAXIMUM_NR_OF_VERTICES_ON_SURFACE'
